@@ -80,15 +80,15 @@ class ContactService(BaseRdbmsService):
         information that would be still ongoing.
 
 
-        :param account_id: identification of the account of the user who has
+        @param account_id: identification of the account of the user who has
             confirmed the given contact information.
 
-        :param contact: an instance `Contact` of the contact information that
+        @param contact: an instance `Contact` of the contact information that
             the user has confirmed, and which references to it need to be
             removed from any other user account and ongoing verification
             request.
 
-        :param connection: An object `RdbmsConnection`  with auto commit.
+        @param connection: An object `RdbmsConnection`  with auto commit.
         """
         with self.acquire_rdbms_connection(auto_commit=True, connection=connection) as connection:
             # Remove this contact information from any other user account.
@@ -158,11 +158,11 @@ class ContactService(BaseRdbmsService):
         Enable the contact information of the specified user
 
 
-        :param account_id: The identification of the account of a user.
+        @param account_id: The identification of the account of a user.
 
-        :param contact: The contact information to be enabled.
+        @param contact: The contact information to be enabled.
 
-        :param connection: An object `RdbmsConnection` with auto commit.
+        @param connection: An object `RdbmsConnection` with auto commit.
 
         """
         with self.acquire_rdbms_connection(auto_commit=True, connection=connection) as connection:
@@ -217,10 +217,10 @@ class ContactService(BaseRdbmsService):
         Generate a string composed of the requested number of digits
 
 
-        :param digit_count: Number of digit to generate.
+        @param digit_count: Number of digit to generate.
 
 
-        :return: A string composed of the request number of digits.
+        @return: A string composed of the request number of digits.
         """
         return ''.join([
             str(random.randint(0, 9))
@@ -235,19 +235,19 @@ class ContactService(BaseRdbmsService):
             request_id: uuid.UUID = None):
         """
 
-        :param connection:
-        :param contact:
-        :param verification_code:
-        :param request_id: The identification of the verification request.
+        @param connection:
+        @param contact:
+        @param verification_code:
+        @param request_id: The identification of the verification request.
 
 
-        :return:
+        @return:
 
 
-        :raise DisabledObjectException: If the verification request has
+        @raise DisabledObjectException: If the verification request has
             expired.
 
-        :raise UndefinedObjectException: If the verification request doesn't
+        @raise UndefinedObjectException: If the verification request doesn't
             exist.
         """
         with self.acquire_rdbms_connection(connection=connection) as connection:
@@ -312,11 +312,11 @@ class ContactService(BaseRdbmsService):
         Update a contact verification request status
 
 
-        :param request_id: Identification of a contact verification request.
+        @param request_id: Identification of a contact verification request.
 
-        :param connection: An object `RdbmsConnection` with auto commit.
+        @param connection: An object `RdbmsConnection` with auto commit.
 
-        :param object_status: An item of the enumeration `ObjectStatus`
+        @param object_status: An item of the enumeration `ObjectStatus`
 
             * `deleted`:  The request has been fulfilled.
 
@@ -354,16 +354,16 @@ class ContactService(BaseRdbmsService):
         by a user, indicate whether this contact information has been verified.
 
 
-        :param contact: An object `Contact`.
+        @param contact: An object `Contact`.
 
-        :param account_id: Identification of the account of the user on behalf
+        @param account_id: Identification of the account of the user on behalf
             whom this function is called.
 
-        :param connection: An instance `RdbmsConnection` to be used
+        @param connection: An instance `RdbmsConnection` to be used
             supporting the Python clause `with ...:`.
 
 
-        :return: A tuple containing the following values:
+        @return: A tuple containing the following values:
 
             * `is_available`: `True` if the specified contact information is not
               yet registered by any accounts, or if it has been registered by the
@@ -489,11 +489,11 @@ class ContactService(BaseRdbmsService):
         contact information (cf. function `confirm_contact`).
 
 
-        :note: The function ignores any consecutive call for a same contact
+        @note: The function ignores any consecutive call for a same contact
             information within a minimal duration of time, to avoid spamming
             the user.
 
-        :note: If a verification request was already generated on behalf of
+        @note: If a verification request was already generated on behalf of
             another user, the function will silently disable the association
             between this request and this particular user account.  The client
             application MUST request the user who will confirm this contact
@@ -501,32 +501,32 @@ class ContactService(BaseRdbmsService):
             information to his account.
 
 
-        :warning: The function DOESN'T return the identification of the
+        @warning: The function DOESN'T return the identification of the
             verification request so that this identification CANNOT be passed
             to the client application.  Indeed!
 
 
-        :param contact: An instance `Contact`.
+        @param contact: An instance `Contact`.
 
-        :param account_id: Identification of the account of the user who
+        @param account_id: Identification of the account of the user who
             requests to get his contact information verified.  This argument
             can be `None` when this contact information needs to be verified
             prior to the user account to be created.
 
-        :param connection: A `RdbmsConnection` instance to be used  supporting
+        @param connection: A `RdbmsConnection` instance to be used  supporting
             the Python clause `with ...:`.
 
-        :param context: A JSON expression corresponding to the context in
+        @param context: A JSON expression corresponding to the context in
             this contact information has been added and needs to be verified.
 
-        :param language: An object `Locale` referencing the language in which
+        @param language: An object `Locale` referencing the language in which
             to generate the contact information verification request.
 
-        :param verification_code_length: Number of digits to generate the
+        @param verification_code_length: Number of digits to generate the
             verification code.
 
 
-        :raise IllegalAccessException: If a verification of this contact
+        @raise IllegalAccessException: If a verification of this contact
             information has been already requested for another account.
         """
         with self.acquire_rdbms_connection(auto_commit=True, connection=connection) as connection:
@@ -638,30 +638,30 @@ class ContactService(BaseRdbmsService):
         Indicate whether the specified contact verification request exists.
 
 
-        :param connection: An object `RdbmsConnection`.
+        @param connection: An object `RdbmsConnection`.
 
-        :param contact: The contact information that the user is verifying.
+        @param contact: The contact information that the user is verifying.
             The argument `activation_code` MUST be also passed to this
             function.
 
-        :param request_id: identification of the contact verification request.
+        @param request_id: identification of the contact verification request.
 
-        :param verification_code: A pseudo-random number (nonce) that was
+        @param verification_code: A pseudo-random number (nonce) that was
             generated and sent to the user to verify his contact information.
             The argument `contact` MUST be also passed to this function.
 
 
-        :return: `True` if the specified identification corresponds to a
+        @return: `True` if the specified identification corresponds to a
             contact verification request registered to the platform;
             `False` otherwise.
 
 
-        :raise DisabledObjectException: If the contact verification request
+        @raise DisabledObjectException: If the contact verification request
             has expired.
 
-        :raise IllegalAccessException: If the verification code is not valid.
+        @raise IllegalAccessException: If the verification code is not valid.
 
-        :raise UndefinedObjectException: If the verification code doesn't
+        @raise UndefinedObjectException: If the verification code doesn't
             exist.  It may be an expired request that has been deleted.
         """
         request = self.__get_contact_verification_request(
@@ -692,15 +692,15 @@ class ContactService(BaseRdbmsService):
         Return a dictionary of contacts group by their name.
 
 
-        :param contacts: A list of objects `Contact`.
+        @param contacts: A list of objects `Contact`.
 
 
-        :return: A dictionary where the key corresponds to an item of
+        @return: A dictionary where the key corresponds to an item of
             `ContactName` and the value a list of contacts that correspond
             to this contact type.
 
 
-        :raise AssertError: If a contact information is duplicated.
+        @raise AssertError: If a contact information is duplicated.
         """
         contacts_by_property_name = collections.defaultdict(list)
 
@@ -721,19 +721,19 @@ class ContactService(BaseRdbmsService):
         second list.
 
 
-        :note: the function also automatically sets the attribute `is_primary`
+        @note: the function also automatically sets the attribute `is_primary`
             of contact instances to `False` when a contact of the same name is
             in the second list and its attribute `is_primary` is `True`.
 
 
-        :param from_contacts: a list of contacts to subtract contacts that are
+        @param from_contacts: a list of contacts to subtract contacts that are
             in the second list.
 
-        :param with_contacts: a list of contacts to be removed from the first
+        @param with_contacts: a list of contacts to be removed from the first
             list of contacts.
 
 
-        :return: a list with contacts in the first list that are not in the
+        @return: a list with contacts in the first list that are not in the
             second list.
         """
         contact_set1 = cls.__group_contacts_by_property_name(from_contacts)
@@ -785,38 +785,38 @@ class ContactService(BaseRdbmsService):
         would have been generated to verify this contact information.
 
 
-        :param account_id: identification of the account of the user who adds
+        @param account_id: identification of the account of the user who adds
             his contact information.
 
-        :param contact: An object `Contact`.
+        @param contact: An object `Contact`.
 
-        :param connection: An object `RdbmsConnection` with auto commit.
+        @param connection: An object `RdbmsConnection` with auto commit.
 
-        :param context: A JSON expression corresponding to the context
+        @param context: A JSON expression corresponding to the context
             in which this contact has been added and need to be verified.
             This parameter is only used if the parameter `to_be_verified` is
             set to `True`.
 
-        :param has_been_verified: Indicate whether this contact information
+        @param has_been_verified: Indicate whether this contact information
             has been verified through a challenge/response process.  This
             parameter is intended to be set by the function `confirm_contact`
             only.
 
-        :param language: An object `Locale` representing the language in which
+        @param language: An object `Locale` representing the language in which
             to write the email verification request in.
 
-        :param to_be_verified: Indicate whether the platform needs to send a
+        @param to_be_verified: Indicate whether the platform needs to send a
             request to the user to verify his contact information.  This
             argument cannot be set to `True` if the argument `has_been_verified`
             has been set to `True`.
 
-        :param verification_code_length: Number of digits to generate the
+        @param verification_code_length: Number of digits to generate the
             verification code.
 
-        :raise ContactAlreadyUsedException: if one of the contacts has been
+        @raise ContactAlreadyUsedException: if one of the contacts has been
             already registered and verified by another user.
 
-        :raise InvalidArgumentException: if this contact information is stated
+        @raise InvalidArgumentException: if this contact information is stated
             as verified while no challenge process has been passed.
         """
         assert not (has_been_verified and to_be_verified), "Conflicted values"
@@ -960,29 +960,29 @@ class ContactService(BaseRdbmsService):
         information as the primary.
 
 
-        :warning: this function MUST NOT be directly surfaced to any client
+        @warning: this function MUST NOT be directly surfaced to any client
             application, but SHOULD be used by the server controller of a
             client application.
 
 
-        :param app_id: identification of the client application such as a Web,
+        @param app_id: identification of the client application such as a Web,
             a desktop, or a mobile application, that accesses the service.
 
-        :param connection: An object `RdbmsConnection` with auto commit.
+        @param connection: An object `RdbmsConnection` with auto commit.
 
-        :param contact: The contact information that the user is verifying.
+        @param contact: The contact information that the user is verifying.
             The argument `verification_code` MUST be also passed to this
             function.
 
-        :param request_id: identification of the verification request that has
+        @param request_id: identification of the verification request that has
             been sent to the user.
 
-        :param verification_code: A pseudo-random number (nonce) that was
+        @param verification_code: A pseudo-random number (nonce) that was
             generated and sent to the user to verify his contact information.
             The argument `contact` MUST be also passed to this function.
 
 
-        :return: The function returns an instance `contact` or a tuple of
+        @return: The function returns an instance `contact` or a tuple of
             instances `contact, session` depending on whether the parameter
             `auto_sign_in` has been set to, respectively `False`, or
             `True`:
@@ -1021,13 +1021,13 @@ class ContactService(BaseRdbmsService):
                   parameter `auto_sign_in`).
 
 
-        :raise DeletedObjectException: if the user account has been deleted
+        @raise DeletedObjectException: if the user account has been deleted
             while the argument `check_status` has been set to `True`.
 
-        :raise DisabledObjectException: if the user account has been disabled
+        @raise DisabledObjectException: if the user account has been disabled
             while the argument `check_status` has been set to `True`.
 
-        :raise UndefinedObjectException: if the specified identification
+        @raise UndefinedObjectException: if the specified identification
             doesn't refer to a user account registered against the platform.
         """
         if request_id is None and verification_code is None:
@@ -1093,12 +1093,12 @@ class ContactService(BaseRdbmsService):
         Return the account that matches a contact.
 
 
-        :param contact: An object `Contact`.
+        @param contact: An object `Contact`.
 
-        :param connection: An object `RdbmsConnection`.
+        @param connection: An object `RdbmsConnection`.
 
 
-        :return: `None` if no account matches the specified contact, or an
+        @return: `None` if no account matches the specified contact, or an
             object containing the following attributes:
 
             * `account_id` (required): Identification of the account.
@@ -1144,13 +1144,13 @@ class ContactService(BaseRdbmsService):
         Return the request send to a user to verify his contact information.
 
 
-        :note: this function MUST not be surfaced to client applications.
+        @note: this function MUST not be surfaced to client applications.
 
 
-        :param contact: an instance `Contact`.
+        @param contact: an instance `Contact`.
 
 
-        :return: an instance containing the following members:
+        @return: an instance containing the following members:
 
             * `account_id` (optional): identification of the account of the user
               who requested to verify his contact information, if he was logged in
@@ -1192,22 +1192,22 @@ class ContactService(BaseRdbmsService):
 
     def get_contacts(
             self,
-            account_id,
-            connection=None,
-            property_name=None):
+            account_id: uuid.UUID,
+            connection: RdbmsConnection = None,
+            property_name: ContactName = None) -> list[Contact]:
         """
-        Return the list of contact information of an account
+        Return the list of contact information of a user account.
 
 
-        :param account_id: Identification of a user account.
+        @param account_id: The identification of a user account.
 
-        :param connection: An object `RdbmsConnection`.
+        @param connection: RdbmsConnection: An existing connection to the
+            user account database.
 
-        :param property_name: An item of the enumeration `ContactName` to
-            filter the list of contact information of the user.
+        @param property_name: The category of contact information to return.
 
 
-        :return: A list of `Contact` objects.
+        @return: A list of the user's contact information.
         """
         with self.acquire_rdbms_connection(connection=connection) as connection:
             cursor = connection.execute(
@@ -1228,7 +1228,8 @@ class ContactService(BaseRdbmsService):
                     'OBJECT_STATUS_ENABLED': ObjectStatus.enabled,
                     'account_id': account_id,
                     'property_name': property_name,
-                })
+                }
+            )
 
             contacts = [
                 Contact.from_object(row.get_object())
@@ -1252,22 +1253,22 @@ class ContactService(BaseRdbmsService):
         alternates.
 
 
-        :param account_id: The identification of the account of a user.
+        @param account_id: The identification of the account of a user.
 
-        :param contact: An object `Contact` of the contact information of
+        @param contact: An object `Contact` of the contact information of
             the user to set as primary.  The attribute `is_verified` of this
             object MUST be `True`.
 
-        :param add_if_not_exists: Indicate whether to add this contact
+        @param add_if_not_exists: Indicate whether to add this contact
             information if it doesn't not exist.
 
-        :param connection: An object `RdbmsConnection` with auto commit.
+        @param connection: An object `RdbmsConnection` with auto commit.
 
 
-        :raise InvalidOperationException: If the contact information has not
+        @raise InvalidOperationException: If the contact information has not
             been verified yet.
 
-        :raise UndefinedObjectException: If this contact information has not
+        @raise UndefinedObjectException: If this contact information has not
             been associated to this user account.
         """
         if not contact.is_verified:
