@@ -506,7 +506,7 @@ CREATE TABLE account_picture
   --
   -- * `UnevenlyOpenEyelidException`: An eye is more opened/closed than the
   --   other.
-  rejection_exception NULL,
+  rejection_exception text NULL,
 
   -- The current status of the picture:
   --
